==> GCharts-1.0.tar.gz: GCharts/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'GCharts';
$lang['postinstall'] = 'Be sure to set "Use GCharts" permissions to use this module!';
$lang['postuninstall'] = 'Sorry, it\'s not you, it\'s me.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this super fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['submit'] = 'Save';
$lang['cancel'] = 'Cancel';
$lang['addchart'] = 'Add chart';
$lang['charts'] = 'Charts';
$lang['chart'] = 'Chart';
$lang['data'] = 'Data';
$lang['published'] = 'Published';
$lang['draft'] = 'Draft';
$lang['status'] = 'Status';
$lang['select'] = 'Select';
$lang['reassign_category'] = 'Re-assign category';
$lang['delete_selected'] = 'Delete selected';
$lang['nonamegiven'] = 'No name given';
$lang['areyousure_deletemultiple'] = 'Are you sure you want to delete the selected charts?';
$lang['chartadded'] = 'Chart added';
$lang['chartupdated'] = 'Chart updated';
$lang['id'] = 'Chart ID';
$lang['name'] = 'Chart Title';
$lang['element'] = 'Containing element ID';
$lang['enableInteractivity'] = 'Enable interactivity';
$lang['category'] = 'Chart category';
$lang['gcharts_data'] = 'Chart Data';
$lang['axisTitlesPosition'] = 'Axis titles position';
$lang['backgroundColor'] = 'Background Color';
$lang['curveType'] = 'Curve type';
$lang['chartArea'] = 'Chart Area';
$lang['colors'] = 'Colors';
$lang['focusTarget'] = 'Font target';
$lang['fontSize'] = 'Font Size';
$lang['fontName'] = 'Font Name';
$lang['hAxes'] = 'hAxes';
$lang['hAxis'] = 'hAxis';
$lang['height'] = 'Height';
$lang['interpolatedNulls'] = 'Interpolated nulls';
$lang['isStacked'] = 'Is stacked';
$lang['isHtml'] = 'Is HTML';
$lang['is3D'] = 'Is 3D';
$lang['legend'] = 'Legend';
$lang['lineWidth'] = 'Line width';
$lang['slices'] = 'Slices';
$lang['pieSliceBorderColor'] = 'Pie Slice Boarder Color';
$lang['pieSliceText'] = 'Pie Slice Text';
$lang['pieSliceTextStyle'] = 'Pie Slice Text Style';
$lang['pointSize'] = 'Point size';
$lang['reverseCategories'] = 'Reverse Categories';
$lang['sliceVisibilityThreshold'] = 'Slice Visibility Threshold';
$lang['pieResidueSliceColor'] = 'Pie Residue Slice Color';
$lang['pieResidueSliceLabel'] = 'Pie Residue Slice Label';
$lang['titlePosition'] = 'Title position';
$lang['title'] = 'Title';
$lang['theme'] = 'Theme';
$lang['series'] = 'Series';
$lang['titleTextStyle'] = 'Title Text Style';
$lang['tooltip'] = 'Tooltip';
$lang['vAxes'] = 'vAxes';
$lang['vAxis'] = 'vAxis';
$lang['width'] = 'Width';

$lang['areyousure'] = 'Are you sure you want to delete?';
$lang['dash_record_count'] = 'This module handles %s documents';
$lang['alert_no_records'] = 'There have not been any documents added in the GCharts module!';
$lang['help_gcharts_id'] = 'Internally identifier for selecting documents';
$lang['help_description'] = 'Internal parameter used to pass description info when creating or editing a document';
$lang['help_explanation'] = 'Internal parameter used to pass explanation info when creating or editing a document';
$lang['help_module_message'] = 'Internally used parameter for passing messages to user';
$lang['help_gcharts_id'] = 'ID of the chart you want to display.';

$lang['moddescription'] = 'This module add Google Charts to your website.';
$lang['changelog'] = '<ul>
<li>Version 1.0 8 July 2013. Initial Release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module allows for the addition of Google Charts to your website.</p>
<h3>How Do I Use It</h3>
<p>Simply place the module call before your closing body tag with the ID of the chart you want to display <code>{GCharts gcharts_id=\'1\'}</code>, data field accepts smarty variables.</p>
<p>For detailed information as to what values each parameter takes look at the Google Charts documentation <a href="https://google-developers.appspot.com/chart/">https://google-developers.appspot.com/chart/</a></p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gcharts/">GCharts Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, oliverseddon, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2013, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>

==> GCharts-1.2.tar.gz: GCharts/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'GCharts';
$lang['postinstall'] = 'Be sure to set "Use GCharts" permissions to use this module!';
$lang['postuninstall'] = 'Sorry, it\'s not you, it\'s me.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this super fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
$lang['approve'] = 'Set Status to \'Enabled\'';
$lang['revert'] = 'Set Status to \'Disabled\'';
$lang['submit'] = 'Save';
$lang['cancel'] = 'Cancel';
$lang['addchart'] = 'Add chart';
$lang['charts'] = 'Charts';
$lang['chart'] = 'Chart';
$lang['data'] = 'Data';
$lang['published'] = 'Published';
$lang['draft'] = 'Draft';
$lang['status'] = 'Status';
$lang['select'] = 'Select';
$lang['reassign_category'] = 'Re-assign category';
$lang['delete_selected'] = 'Delete selected';
$lang['nonamegiven'] = 'No name given';
$lang['areyousure_deletemultiple'] = 'Are you sure you want to delete the selected charts?';
$lang['chartadded'] = 'Chart added';
$lang['chartupdated'] = 'Chart updated';
$lang['id'] = 'Chart ID';
$lang['name'] = 'Chart Title';
$lang['element'] = 'Containing element ID';
$lang['enableInteractivity'] = 'Enable interactivity';
$lang['category'] = 'Chart category';
$lang['gcharts_data'] = 'Chart Data';
$lang['axisTitlesPosition'] = 'Axis titles position';
$lang['backgroundColor'] = 'Background Color';
$lang['curveType'] = 'Curve type';
$lang['chartArea'] = 'Chart Area';
$lang['colors'] = 'Colors';
$lang['focusTarget'] = 'Font target';
$lang['fontSize'] = 'Font Size';
$lang['fontName'] = 'Font Name';
$lang['hAxes'] = 'hAxes';
$lang['hAxis'] = 'hAxis';
$lang['height'] = 'Height';
$lang['interpolatedNulls'] = 'Interpolated nulls';
$lang['isStacked'] = 'Is stacked';
$lang['isHtml'] = 'Is HTML';
$lang['is3D'] = 'Is 3D';
$lang['legend'] = 'Legend';
$lang['lineWidth'] = 'Line width';
$lang['slices'] = 'Slices';
$lang['pieSliceBorderColor'] = 'Pie Slice Boarder Color';
$lang['pieSliceText'] = 'Pie Slice Text';
$lang['pieSliceTextStyle'] = 'Pie Slice Text Style';
$lang['pointSize'] = 'Point size';
$lang['reverseCategories'] = 'Reverse Categories';
$lang['sliceVisibilityThreshold'] = 'Slice Visibility Threshold';
$lang['pieResidueSliceColor'] = 'Pie Residue Slice Color';
$lang['pieResidueSliceLabel'] = 'Pie Residue Slice Label';
$lang['titlePosition'] = 'Title position';
$lang['title'] = 'Title';
$lang['theme'] = 'Theme';
$lang['series'] = 'Series';
$lang['titleTextStyle'] = 'Title Text Style';
$lang['tooltip'] = 'Tooltip';
$lang['vAxes'] = 'vAxes';
$lang['vAxis'] = 'vAxis';
$lang['width'] = 'Width';
$lang['aggregationTarget'] = 'Aggregation Target';
$lang['groupWidth'] = 'Group Width';
$lang['error_nochartsselected'] = 'No Charts Were Selected';

$lang['areyousure'] = 'Are you sure you want to delete?';
$lang['dash_record_count'] = 'This module handles %s documents';
$lang['alert_no_records'] = 'There have not been any documents added in the GCharts module!';
$lang['help_gcharts_id'] = 'Internally identifier for selecting documents';
$lang['help_description'] = 'Internal parameter used to pass description info when creating or editing a document';
$lang['help_explanation'] = 'Internal parameter used to pass explanation info when creating or editing a document';
$lang['help_module_message'] = 'Internally used parameter for passing messages to user';
$lang['help_gcharts_id'] = 'ID of the chart you want to display.';

$lang['moddescription'] = 'This module add Google Charts to your website.';
$lang['changelog'] = '<ul>
<li>Version 1.0 8 July 2013. Initial Release.</li>
<li>Version 1.1 15 July 2013. Multiple bug fixes.</li>
<li>Version 1.2 14 November 2013. Added column charts option plus many bug fixes.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module allows for the addition of Google Charts to your website.</p>
<h3>How Do I Use It</h3>
<p>Simply place the module call before your closing body tag with the ID of the chart you want to display <code>{GCharts gcharts_id=\'1\'}</code>, data field accepts smarty variables.</p>
<p>For detailed information as to what values each parameter takes look at the Google Charts documentation <a href="https://google-developers.appspot.com/chart/">https://google-developers.appspot.com/chart/</a></p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gcharts/">GCharts Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, oliverseddon, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2013, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>
